@@ -13,7 +13,7 @@ my $keyword = scraper {
     process 'ul.list-circle > li:first-child > a', category => 'TEXT';
 };
 
-my $res = $keyword->(URI->new("http://d.hatena.ne.jp/keyword/%BA%B0%CC%EE%A4%A2%A4%B5%C8%FE"));
+my $res = $keyword->scrape(URI->new("http://d.hatena.ne.jp/keyword/%BA%B0%CC%EE%A4%A2%A4%B5%C8%FE"));
 
 use YAML;
 warn Dump $res;
