@@ -9,7 +9,7 @@ my $nick = shift || "miyagawa";
 my $uri  = URI->new("http://twitter.com/$nick");
 
 my $twitter = scraper {
-    process 'a[rel="contact"]',
+    process 'a[rel=~"contact"]',
         'friends[]' => scraper {
             process 'a',   url => '@href', name => '@title';
             process 'img', src => '@src';
